@@ -1,7 +1,7 @@
 from typing import Any, Dict, Iterable, List, Tuple, FrozenSet, Union
 from abc import ABC, abstractmethod
 from .elements import Element
-
+import pandas
 
 class ChartTextStyle:
     """Class for defining the styling of the text for a chart."""
@@ -506,9 +506,8 @@ class LineSeries(XYSeries):
             color (str, optional): The color in which the series should be shown on a chart.
                 Can be html/css colors or hex values. Defaults to None.
             line_width (str, optional): Thickness of the connecting line in em, pt, px, cm or in. Defaults to None.
-            line_style (str, optional): Style of the line. Supported options can be found online on the [Cloud Office Print documentation](https://www.cloudofficeprint.com/docs/#line). Defaults to None.
+            line_style (str, optional): Style of the line. Supported options can be found online on the Cloud Office Print documentation. Defaults to None.
         """
-        # TODO: update website for line_style argument?
         super().__init__(x, y, name, color)
         self.smooth: bool = smooth
         self.symbol: str = symbol
